import { StrictMode } from 'react';
import { createRoot } from 'react-dom/client';
import { BrowserRouter } from 'react-router-dom';
import App from './App.tsx';
import './index.css';
import { testConnection } from './lib/supabase';

// Enhanced error handling
window.addEventListener('error', (event) => {
  console.error('🚨 Global error:', event.error);
});

window.addEventListener('unhandledrejection', (event) => {
  console.error('🚨 Unhandled promise rejection:', event.reason);
});

// Environment validation
const requiredEnvVars = {
  VITE_SUPABASE_URL: import.meta.env.VITE_SUPABASE_URL,
  VITE_SUPABASE_ANON_KEY: import.meta.env.VITE_SUPABASE_ANON_KEY
};

console.log('🔍 Environment Check:', {
  VITE_SUPABASE_URL: import.meta.env.VITE_SUPABASE_URL ? '✅ Set' : '❌ Missing',
  VITE_SUPABASE_ANON_KEY: import.meta.env.VITE_SUPABASE_ANON_KEY ? '✅ Set' : '❌ Missing',
  NODE_ENV: import.meta.env.NODE_ENV,
  MODE: import.meta.env.MODE,
  DEV: import.meta.env.DEV,
  PROD: import.meta.env.PROD
});

const missingEnvVars = Object.entries(requiredEnvVars)
  .filter(([, value]) => !value)
  .map(([key]) => key);

if (missingEnvVars.length > 0) {
  console.error('❌ Missing environment variables:', missingEnvVars);
  
  // Show user-friendly error page
  document.body.innerHTML = `
    <div style="
      min-height: 100vh;
      display: flex;
      align-items: center;
      justify-content: center;
      font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
      background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
      padding: 20px;
      margin: 0;
    ">
      <div style="
        max-width: 600px;
        background: white;
        padding: 40px;
        border-radius: 16px;
        box-shadow: 0 20px 40px rgba(0,0,0,0.15);
        text-align: center;
      ">
        <div style="font-size: 4rem; margin-bottom: 20px;">🔧</div>
        <h1 style="color: #2d3748; margin-bottom: 20px; font-size: 28px; font-weight: 700;">
          Environment Configuration Issue
        </h1>
        <p style="color: #4a5568; margin-bottom: 25px; line-height: 1.6; font-size: 16px;">
          The Banky Auto website is missing required environment variables.
        </p>
        
        <div style="
          background: #fed7d7;
          border: 1px solid #fc8181;
          border-radius: 8px;
          padding: 20px;
          margin: 25px 0;
          text-align: left;
        ">
          <h3 style="color: #742a2a; margin: 0 0 15px 0; font-size: 16px;">Missing Variables:</h3>
          <ul style="color: #742a2a; margin: 0; padding-left: 20px;">
            ${missingEnvVars.map(envVar => `<li style="margin: 5px 0;"><code style="background: rgba(0,0,0,0.1); padding: 2px 6px; border-radius: 4px;">${envVar}</code></li>`).join('')}
          </ul>
        </div>
        
        <div style="margin-top: 30px; display: flex; gap: 15px; justify-content: center; flex-wrap: wrap;">
          <button onclick="window.location.reload()" style="
            background: linear-gradient(135deg, #48bb78 0%, #38a169 100%);
            color: white;
            padding: 12px 24px;
            border: none;
            border-radius: 8px;
            cursor: pointer;
            font-weight: 600;
            transition: transform 0.2s;
          ">
            🔄 Retry
          </button>
          <a href="/env-check.html" style="
            display: inline-block;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            color: white;
            padding: 12px 24px;
            text-decoration: none;
            border-radius: 8px;
            font-weight: 600;
            transition: transform 0.2s;
          ">
            🔧 Diagnostics
          </a>
        </div>
      </div>
    </div>
  `;
} else {
  console.log('✅ All environment variables present, initializing app...');
  
  // Test Supabase connection before rendering
  testConnection().then(result => {
    if (result.success) {
      console.log('✅ Supabase connection verified');
    } else {
      console.warn('⚠️ Supabase connection issue:', result.error);
    }
  });
  
  try {
    const rootElement = document.getElementById('root');
    if (!rootElement) {
      throw new Error('Root element not found');
    }

    const root = createRoot(rootElement);
    root.render(
      <StrictMode>
        <BrowserRouter>
          <App />
        </BrowserRouter>
      </StrictMode>
    );
    
    console.log('✅ App rendered successfully');
  } catch (error) {
    console.error('❌ Failed to render app:', error);
    
    // Fallback error display
    document.body.innerHTML = `
      <div style="
        min-height: 100vh;
        display: flex;
        align-items: center;
        justify-content: center;
        font-family: Arial, sans-serif;
        background: #f7fafc;
        padding: 20px;
      ">
        <div style="
          max-width: 500px;
          background: white;
          padding: 30px;
          border-radius: 12px;
          box-shadow: 0 4px 12px rgba(0,0,0,0.1);
          text-align: center;
        ">
          <h1 style="color: #e53e3e; margin-bottom: 15px;">Application Error</h1>
          <p style="color: #4a5568; margin-bottom: 20px;">
            Failed to initialize the application: ${error.message}
          </p>
          <button onclick="window.location.reload()" style="
            background: #3182ce;
            color: white;
            padding: 10px 20px;
            border: none;
            border-radius: 6px;
            cursor: pointer;
          ">
            Reload Page
          </button>
        </div>
      </div>
    `;
  }
}